# Changelog

## 1.0.0 (2025-10-20)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/harshapalnati/Ractor-sdk-python/compare/v0.0.1...v1.0.0)

### Chores

* update SDK settings ([8c2663b](https://github.com/harshapalnati/Ractor-sdk-python/commit/8c2663b20981e2d65f7c4af734f785ad17d5f58c))
* update SDK settings ([35446d3](https://github.com/harshapalnati/Ractor-sdk-python/commit/35446d3ce2c2f19b0550253e75e2422fd44c3912))
